Skip to contents

Metadata extracted from CrossRef using the rcrossref package for scientific publications referenced in the parametra_long dataset

Usage

crossref

Format

A data frame.

Compiled from various scientific publications; see the "ref" column.

Details

Columns:

id

Parameter identifier

ref

Reference: source DOI or URL

ref_last_access

Date reference was automatically checked for the last time

ref_status

Reference status in the last aoutomatic check