Skip to contents

Diagnostic test parameters such as test specificity and sensitivity

Usage

diagnostic_test

Format

A data frame.

Compiled from various scientific publications; see the "ref" column.

Details

Columns:

filled_by

Data entry person identifier

filled_date

Data entry date

host

Host species

host_age

Age or age group of host

host_breed

Specific breed of host

host_other

Additional host characteristics

host_type

Type of host

id

Parameter identifier

lower_cl

Lower bound of confidence/credible interval

parameter

Parameter measured

pathogen

Name of the infectious agent

ref

Reference: source DOI or URL

ref_last_access

Date reference was automatically checked for the last time

ref_short

Short reference: source author and year

ref_status

Reference status in the last aoutomatic check

remarks

Additional notes or comments

sample_type

Type of biological sample used

study_type

Study type

test_type

Type of diagnostic test used

upper_cl

Upper bound of confidence/credible interval

value

Numeric value of the parameter

year

Year of publication