Skip to contents

Survival parameters in different materials and environmental conditions

Usage

pathogen_survival

Format

A data frame.

Compiled from various scientific publications; see the "ref" column.

Details

Columns:

filled_by

Data entry person identifier

filled_date

Data entry date

id

Parameter identifier

if_other

Additional parameter specifications

material

Type of material or medium where survival was measured

parameter

Parameter measured

pathogen

Name of the infectious agent

ref

Reference: source DOI or URL

ref_last_access

Date reference was automatically checked for the last time

ref_short

Short reference: source author and year

ref_status

Reference status in the last aoutomatic check

remarks

Additional notes or comments

study_type

Study type

variant_strain

Specific variant or strain

year

Year of publication