Information about disease control programs and plans implemented in different countries
Details
Columns:
- country
Country or region where data was collected
- country_disease_status
Disease status classification
- filled_by
Data entry person identifier
- host
Host species
- host_age
Age or age group of host
- host_breed
Specific breed of host
- host_other
Additional host characteristics
- host_type
Type of host
- id
Parameter identifier
- last_updated
Date of last control plan update
- pathogen
Name of the infectious agent
- plan_coverage
Geographical scope of the plan
- plan_implemented
Whether a control plan is implemented
- plan_type
Type of control plan
- plan_voluntary_compulsary
Voluntary or compulsory plan
- ref
Reference: source DOI or URL
- ref_last_access
Date reference was automatically checked for the last time
- ref_short
Short reference: source author and year
- ref_status
Reference status in the last aoutomatic check
- remarks
Additional notes or comments
- year
Year of publication