Metadata extracted from CrossRef using the rcrossref package for scientific publications referenced in the parametra_long dataset
Metadata extracted from CrossRef using the rcrossref package for scientific publications referenced in the parametra_long dataset