Infectious period, latent period, incubation period, shape and other disease period parameters
Details
Columns:
- estimation_method
Method used for estimation
- estimation_type
Statistical approach used (Frequentist/Bayesian)
- filled_by
Data entry person identifier
- filled_date
Data entry date
- host
Host species
- host_age
Age or age group of host
- host_breed
Specific breed of host
- host_other
Additional host characteristics
- host_type
Type of host
- id
Parameter identifier
- if_other
Additional parameter specifications
- inoculated_contact
Inoculation of contact status
- lower_cl
Lower bound of confidence/credible interval
- parameter
Parameter measured
- pathogen
Name of the infectious agent
- ref
Reference: source DOI or URL
- ref_last_access
Date reference was automatically checked for the last time
- ref_short
Short reference: source author and year
- ref_status
Reference status in the last aoutomatic check
- remarks
Additional notes or comments
- scale
Scale of the study
- study_type
Study type
- unit
Units of measurement
- upper_cl
Upper bound of confidence/credible interval
- vaccine
Type of vaccine used if applicable
- value
Numeric value of the parameter
- variant_strain
Specific variant or strain
- year
Year of publication